==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/Stacked100BarSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StackedBarSeriesDescriptionMetadata } from "./StackedBarSeriesDescriptionMetadata";
import { Stacked100BarSeriesDescription } from "./Stacked100BarSeriesDescription";
/**
 * @hidden
 */
export let Stacked100BarSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class Stacked100BarSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (Stacked100BarSeriesDescriptionMetadata.a == null) {
                Stacked100BarSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                Stacked100BarSeriesDescriptionMetadata.c(Stacked100BarSeriesDescriptionMetadata.a);
            }
            if (a.k(Stacked100BarSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ab(Stacked100BarSeriesDescriptionMetadata.a);
        }
        static c(a) {
            StackedBarSeriesDescriptionMetadata.c(a);
        }
        static d(a) {
            Stacked100BarSeriesDescriptionMetadata.b(a);
            a.ad("Stacked100BarSeries", () => new Stacked100BarSeriesDescription());
            a.ac("Stacked100BarSeries", Stacked100BarSeriesDescriptionMetadata.a);
        }
    }
    Stacked100BarSeriesDescriptionMetadata.$t = markType(Stacked100BarSeriesDescriptionMetadata, 'Stacked100BarSeriesDescriptionMetadata');
    Stacked100BarSeriesDescriptionMetadata.a = null;
    return Stacked100BarSeriesDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/Stacked100BarSeriesDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { StackedBarSeriesDescriptionMetadata } from "./StackedBarSeriesDescriptionMetadata";
import { Stacked100BarSeriesDescription } from "./Stacked100BarSeriesDescription";
/**
 * @hidden
 */
export let Stacked100BarSeriesDescriptionMetadata = /*@__PURE__*/ (() => {
    class Stacked100BarSeriesDescriptionMetadata extends Base {
        static b(a) {
            if (Stacked100BarSeriesDescriptionMetadata.a == null) {
                Stacked100BarSeriesDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                Stacked100BarSeriesDescriptionMetadata.c(Stacked100BarSeriesDescriptionMetadata.a);
            }
            if (a.k(Stacked100BarSeriesDescriptionMetadata.a)) {
                return;
            }
            a.ac(Stacked100BarSeriesDescriptionMetadata.a);
        }
        static c(a) {
            StackedBarSeriesDescriptionMetadata.c(a);
        }
        static d(a) {
            Stacked100BarSeriesDescriptionMetadata.b(a);
            a.ae("Stacked100BarSeries", () => new Stacked100BarSeriesDescription());
            a.ad("Stacked100BarSeries", Stacked100BarSeriesDescriptionMetadata.a);
        }
    }
    Stacked100BarSeriesDescriptionMetadata.$t = markType(Stacked100BarSeriesDescriptionMetadata, 'Stacked100BarSeriesDescriptionMetadata');
    Stacked100BarSeriesDescriptionMetadata.a = null;
    return Stacked100BarSeriesDescriptionMetadata;
})();
